@@ -5,6 +5,7 @@ import importlib
 import importlib.machinery
 
 import importlib.util
+from pathlib import Path
 
 from typing import List
 from .targets import TargetList
@@ -50,6 +51,9 @@ def get_generator_list(root: str, path: str = "") -> List[str]:
 
     generators = []
 
+    if not Path(root).exists():
+        raise FileNotFoundError(f"{root} not exist!")
+
     for root, _, files in os.walk(root):
         for file in files:
             full_path = os.path.join(root, file)
